internal/encoder/percent_encoding
Percent Encodes strings according to RFC 3986.
See the following links for reference:
Values
pub fn encode_string(
encode string: String,
start position: Int,
maximum_size maximum_size: Int,
) -> Result(List(String), encoding.EncoderError)
Percent encode a string, taking the maximum line size into account and pretending to start the first line at the passed start position.
pub fn estimate_encoded_size(
of string: String,
maximum_size maximum_size: Int,
) -> Result(Int, encoding.EncoderError)
Estimates the percent encoded size of a string in bytes, taking maximum size of a line into account.