internal/encoder/quoted_printable

Encodes quoted-printable strings according to RFC 2045 and RFC 2047.

See the following links for reference:

Values

pub fn encode_string(
  encode string: String,
  enforce rfc: encoding.Rfc,
  start position: Int,
  preferred_size preferred_size: Int,
) -> Result(List(String), encoding.EncoderError)

Quoted printable encode a string, taking the desired RFC constraints and the preferred line size into account, and pretending to start the first line at the passed start position.

pub fn estimate_encoded_size(
  of string: String,
  enforce rfc: encoding.Rfc,
) -> Result(Int, encoding.EncoderError)

Estimates the quoted printable encoded size of a string in bytes, taking the desired RFC constraints into account.

Search Document