internal/encoder/base64
Encode base64 strings according to RFC 2045.
See the following link for reference:
Values
pub fn encode_string(
encode string: String,
start position: Int,
preferred_size preferred_size: Int,
) -> Result(List(String), encoding.EncoderError)
Base64 encode a string, taking the preferred line size into account and pretending to start the first line at the passed start position.
pub fn estimate_encoded_size(
of string: String,
) -> Result(Int, encoding.EncoderError)
Estimates the base64 encoded size of a string in bytes.